.. _networking:

==================
Networking service
==================

.. toctree::
   :maxdepth: 1

   overview.rst
   common/get-started-networking.rst
   concepts.rst
   install-obs.rst
   install-rdo.rst
   install-ubuntu.rst

This chapter explains how to install and configure the Networking
service (neutron) using the :ref:`provider networks <network1>` or
:ref:`self-service networks <network2>` option.

For more information about the Networking service including virtual
networking components, layout, and traffic flows, see the
:doc:`OpenStack Networking Guide </admin/index>`.
